@@ -40,6 +40,7 @@ from apeye import URL
 from domdf_python_tools.iterative import natmin
 from domdf_python_tools.paths import PathPlus, in_directory
 from domdf_python_tools.typing import PathLike
+from domdf_python_tools.words import word_join
 from email_validator import EmailSyntaxError, validate_email  # type: ignore
 from natsort import natsorted, ns
 from packaging.specifiers import InvalidSpecifier, Specifier, SpecifierSet
@@ -369,7 +370,7 @@ class PEP621Parser(AbstractConfigParser):
 		:param config: The unparsed TOML config for the ``[project]`` table.
 		"""
 
-		license = config["license"]  # noqa: A001
+		license = config["license"]  # noqa: A001  # pylint: disable=redefined-builtin
 
 		if "text" in license and "file" in license:
 			raise BadConfigError(
@@ -618,11 +619,13 @@ class PEP621Parser(AbstractConfigParser):
 			raise BadConfigError("The 'project.name' field must be provided.")
 
 		if dynamic_fields:
-			# TODO
-			if any(f not in {"classifiers", "requires-python", "dependencies"} for f in dynamic_fields):
-				raise BadConfigError(
-						"whey only supports 'classifiers', 'dependencies', and 'requires-python' as dynamic fields."
-						)
+			# TODO: Support the remaining fields as dynamic
+
+			supported_dynamic = ("classifiers", "requires-python", "dependencies")
+
+			if any(f not in supported_dynamic for f in dynamic_fields):
+				supported = word_join(supported_dynamic, oxford=True, use_repr=True)
+				raise BadConfigError(f"whey only supports {supported} as dynamic fields.")
 
 		if "version" not in config:
 			raise BadConfigError("The 'project.version' field must be provided.")
@@ -651,7 +654,7 @@ class WheyParser(AbstractConfigParser):
 		"""
 		Parse the ``package`` key, giving the name of the importable package.
 
-		This defaults to `[project.name] <https://www.python.org/dev/peps/pep-0621/#name>`_ if unspecified.
+		This defaults to `project.name <https://www.python.org/dev/peps/pep-0621/#name>`_ if unspecified.
 
 		:param config: The unparsed TOML config for the ``[tool.whey]`` table.
 		"""
@@ -678,8 +681,8 @@ class WheyParser(AbstractConfigParser):
 	def parse_additional_files(self, config: Dict[str, TOML_TYPES]) -> List[str]:
 		"""
 		Parse the ``additional-files`` key,
-		giving `MANIFEST.in <https://packaging.python.org/guides/using-manifest-in/>`_
-		style entries for additional files to include in distributions.
+		giving `MANIFEST.in <https://packaging.python.org/guides/using-manifest-in/>`_-style
+		entries for additional files to include in distributions.
 
 		:param config: The unparsed TOML config for the ``[tool.whey]`` table.
 		"""  # noqa: D400
@@ -786,6 +789,8 @@ def backfill_classifiers(config: Dict[str, TOML_TYPES]) -> List[str]:
 	:param config: The parsed config from ``pyproject.toml``.
 	"""  # noqa: D400
 
+	# TODO: Typing :: Typed
+
 	parsed_classifiers = set(config["base-classifiers"])
 
 	platforms = config["platforms"]
@@ -866,7 +871,7 @@ def load_toml(filename: PathLike):
 	parsed_config.setdefault("readme", None)
 
 	# tool.whey
-	parsed_config.setdefault("package", parsed_config.get("name"))
+	parsed_config.setdefault("package", config["project"]["name"].replace('.', '/'))
 	parsed_config.setdefault("additional-files", [])
 	parsed_config.setdefault("license-key", None)
 	parsed_config.setdefault("base-classifiers", [])
